OC.L10N.register(
    "settings",
    {
    "Delete" : "తొలగించు",
    "Server address" : "సేవకి చిరునామా",
    "Cancel" : "రద్దుచేయి",
    "Email" : "ఈమెయిలు",
    "Your email address" : "మీ ఈమెయిలు చిరునామా",
    "Password" : "సంకేతపదం",
    "New password" : "కొత్త సంకేతపదం",
    "Language" : "భాష",
    "Name" : "పేరు",
    "Username" : "వాడుకరి పేరు",
    "Personal" : "వ్యక్తిగతం",
    "Error" : "పొరపాటు"
},
"nplurals=2; plural=(n != 1);");
